package com.os.ems.base.service.impl;

import java.util.List;
import com.os.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.ems.base.mapper.EmsBaseMonitorInfoMapper;
import com.os.ems.base.domain.EmsBaseMonitorInfo;
import com.os.ems.base.service.IEmsBaseMonitorInfoService;

/**
 * 计量设备信息Service业务层处理
 * 
 * @author Yinq
 * @date 2024-05-08
 */
@Service
public class EmsBaseMonitorInfoServiceImpl implements IEmsBaseMonitorInfoService 
{
    @Autowired
    private EmsBaseMonitorInfoMapper emsBaseMonitorInfoMapper;

    /**
     * 查询计量设备信息
     * 
     * @param objId 计量设备信息主键
     * @return 计量设备信息
     */
    @Override
    public EmsBaseMonitorInfo selectEmsBaseMonitorInfoByObjId(Long objId)
    {
        return emsBaseMonitorInfoMapper.selectEmsBaseMonitorInfoByObjId(objId);
    }

    /**
     * 查询计量设备信息列表
     * 
     * @param emsBaseMonitorInfo 计量设备信息
     * @return 计量设备信息
     */
    @Override
    public List<EmsBaseMonitorInfo> selectEmsBaseMonitorInfoList(EmsBaseMonitorInfo emsBaseMonitorInfo)
    {
        return emsBaseMonitorInfoMapper.selectEmsBaseMonitorInfoList(emsBaseMonitorInfo);
    }

    /**
     * 新增计量设备信息
     * 
     * @param emsBaseMonitorInfo 计量设备信息
     * @return 结果
     */
    @Override
    public int insertEmsBaseMonitorInfo(EmsBaseMonitorInfo emsBaseMonitorInfo)
    {
        emsBaseMonitorInfo.setCreateTime(DateUtils.getNowDate());
        return emsBaseMonitorInfoMapper.insertEmsBaseMonitorInfo(emsBaseMonitorInfo);
    }

    /**
     * 修改计量设备信息
     * 
     * @param emsBaseMonitorInfo 计量设备信息
     * @return 结果
     */
    @Override
    public int updateEmsBaseMonitorInfo(EmsBaseMonitorInfo emsBaseMonitorInfo)
    {
        emsBaseMonitorInfo.setUpdateTime(DateUtils.getNowDate());
        return emsBaseMonitorInfoMapper.updateEmsBaseMonitorInfo(emsBaseMonitorInfo);
    }

    /**
     * 批量删除计量设备信息
     * 
     * @param objIds 需要删除的计量设备信息主键
     * @return 结果
     */
    @Override
    public int deleteEmsBaseMonitorInfoByObjIds(Long[] objIds)
    {
        return emsBaseMonitorInfoMapper.deleteEmsBaseMonitorInfoByObjIds(objIds);
    }

    /**
     * 删除计量设备信息信息
     * 
     * @param objId 计量设备信息主键
     * @return 结果
     */
    @Override
    public int deleteEmsBaseMonitorInfoByObjId(Long objId)
    {
        return emsBaseMonitorInfoMapper.deleteEmsBaseMonitorInfoByObjId(objId);
    }
}
